#
# spec file for package scrot
#
# Copyright (c) 2024 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


Name:           scrot
Version:        1.11.1
Release:        1.3
Summary:        Screenshot Capture Utility
License:        SUSE-Scrot
Group:          Productivity/Graphics/Other
URL:            https://github.com/resurrecting-open-source-projects/scrot
Source:         https://github.com/resurrecting-open-source-projects/scrot/releases/download/%{version}/%{name}-%{version}.tar.gz
BuildRequires:  pkgconfig
BuildRequires:  update-desktop-files
BuildRequires:  pkgconfig(imlib2)
BuildRequires:  pkgconfig(libbsd)
BuildRequires:  pkgconfig(xcomposite)
BuildRequires:  pkgconfig(xcursor)
BuildRequires:  pkgconfig(xext)
BuildRequires:  pkgconfig(xfixes)
BuildRequires:  pkgconfig(xinerama)
BuildRequires:  pkgconfig(zlib)

%description
A nice and straightforward screen capture utility implementing
the dynamic loaders of imlib2.

%prep
%autosetup -p1

%build
%configure --with-libbsd
%make_build

%install
%make_install
mkdir -p %{buildroot}/%{_datadir}/pixmaps/
rm -rf %{buildroot}/%{_datadir}/doc/scrot

%files
%doc AUTHORS ChangeLog README.md
%license COPYING
%{_bindir}/%{name}
%{_mandir}/man1/%{name}.1%{?ext_man}

%changelog
* Tue Aug 13 2024 Dirk Müller <dmueller@suse.com>
- update to 1.11.1:
  * Fixes: remove trailing slash from etc/ from Makefile.am to
    allow the 'make dist' command to run correctly.
* Thu Jul 25 2024 ming li <mli@suse.com>
- update to 1.11:
  * New feature: zsh and bash completion
  * Improvement: more detailed --help output and new --list-options flag
  * Improvement: better error reporting on newer imlib2 versions
  * Improvement: better handle mutually exclusive options
  * Improvement: --stack no longer errors out if no compositor is running
  * Improvement: print a warning if output file was changed
  * Improvement: default file-name extension is now based on the format used
  * Improvement: selection line mode will be automatically set to "edge"
    mode if no compositors is running
  * Improvement: rewrite autogen.sh to be simpler and more robust
  * Document: add examples of using scrot with other utilities in manpage
  * Document: Correct strftime section in the manual
  * Fixes: selection borders appearing in the screenshot
  * Fixes: reject filenames with trailing slash
  * Fixes: incorrect line opacity mapping
  * Fixes: don't return 0 on exec failure
  * Fixes: bad extension detection
  * Fixes: stricter optional argument parsing
  * Fixes: buffer overrun due to bad x,y in imlib_create_image_from_ximage call
  * Fixes: printing potentially truncated file-size
  * Fixes: various memory leaks
  * Fixes: replace dprintf() calls to fix the SmartOS port
* Mon Sep 11 2023 Paolo Stivanin <info@paolostivanin.com>
- update to 1.10.0:
  * New option: --compression to specify a compression level.
    Note that certain formats (such as PNG) will now use --compression instead of --quality.
  * Improvement: Timing in scrot --delay.
  * Improvement: Screenshot timestamps timing.
  * Document: Not all compositors support opacity.
  * Document: Depend on an interface, not an implementation.
  * Document: Fixed license to MIT-feh. NOTE: this is NOT a license change,
    we simply fixed the document to correctly identify the license.
  * Document: Make it clear --window option takes an argument.
  * Document: Clarify imlib2 feature requirement.
  * Document: Fix --quality description in manpage.
  * Improvement: Fatally error out in case the mouse pointer image cannot be acquired.
  * Deprecate: --note.
  * Fixes: Memory leak.
  * Several other fixes.
* Sat Jan 28 2023 Dirk Müller <dmueller@suse.com>
- update to 1.8.1:
  * Fixed libbsd feature test confusion. Rationale: users expressed confusion
  when using the old "--without-libbsd" configure flag. Some assumed that it
  compiles scrot without libbsd, but it only made the build script error if
  libbsd is a dependency. This is useful to package maintainers: it gives them
  a yes/no answer on whether the library is a dependency on their system. The
  old configure flag has been replaced by a more verbose
  "--enable-libbsd-feature-test".
  * Fixed 'make dist', adding some files to bootstrapped tarballs.
* Tue Jan 10 2023 Paolo Stivanin <info@paolostivanin.com>
- Update to 1.8:
  * Created FAQ file.
  * Improvement: added new format specifier $W: name of the window.
  * Bug fixed: issue when not showing counting progress in terminal.
  * Fixes: memleak and potentially bad free data.
  * Fixes: autotools: respect --docdir.
  * New option: added -M/--monitor option to capture a Xinerama display.
  * Added new library dependency: libXinerama.
  * Several other code fixes and improvements.
* Thu Feb 24 2022 Bjørn Lie <bjorn.lie@gmail.com>
- Drop the unneeded nor used pkgconfig(giblib) BuildRequires: it
  was removed upstream in version 1.6
* Sat Dec 11 2021 Andreas Stieger <andreas.stieger@gmx.de>
- scrot 1.7:
  * Fixed: free memory image and font resources.
  * Fixed: segfault if mouse cursor image was not obtained.
  * Improvement option: --stack, add an optional join direction (v/h).
  * New option: --file (-F), provide the filename as an option.
  * New option: --ignorekeyboard (-i), Don't exit for keyboard input. ESC still exits.
  * New option: --select=hole (-shole), hole selection area.
  * New option: --select=hide (-shide), hide selection area, support image.
  * New option: --select=blur (-sblur), blur selection area.
  * New option: (-) add redirection to standard output (format PNG).
* Tue Jul 27 2021 Paolo Stivanin <info@paolostivanin.com>
- Update to 1.6:
  * Avoid capturing the selection box when drag and drop quickly.
  * Fixed the capture when a window is hidden behind another.
  * Fixed the capture of the edge of the focused window.
  * Fixed issue when selection reaches the end of screen.
  * Fixed Control Flow Integrity complain in HardenedBSD.
  * Improvement: selection option, capture the mouse cursor when
    the delay option is used.
  * New feature: resize the selection with the arrow keys.
  * New feature: support script Imlib2 commands.
  * New feature: added WM_CLASS to exclude selection mode edge from
    some composite window managers.
  * New feature: change the cursor pointer according to the
    movement of the selection.
  * Removed forced compiler options: -g -O3
  * Removed dependence on giblib library.
  * Several improvements over the source code.
* Fri Feb 12 2021 Paolo Stivanin <info@paolostivanin.com>
- Update to 1.5:
  * New feature: retry to grab the keyboard for 1s in 50ms intervals
    if it is still being grabbed by the windows manager.
  * Do not record pointer when selecting an area.
  * Fixed a possible overflow in src/options.c.
  * Fixed a segfault with --multidisp option.
  * Fixed issues when file extension is more than 3 characters.
  * New feature: allow save thumbnail without extension.
  * New option --class (-C): discriminate windows by class name.
  * Support various modes of drawing selection.
  * Use correct type for calloc and other assignments.
* Fri Jul 24 2020 Paolo Stivanin <info@paolostivanin.com>
- Update to 1.4:
  * Added a new logo 128x128.
  * New Feature: capture stack/overlapping windows.
    Depends of libXcomposite (X11). New option: --stack or -k.
  * Call XCloseDisplay on exit. This is the right thing in every
    X server program, to release acquired resources.
  * Fixed autoselect.
  * Fixed capturing partially hidden windows on the edge of the desktop.
  * Fixed required number.
  * Fixed SIGSEGV, if running without DISPLAY environment variable.
  * Fixed SIGSEGV, option --note.
  * Minor fix: variable is assigned that is never used.
  * Stack windows: client list spec EWMH.
* Wed May 13 2020 Paolo Stivanin <info@paolostivanin.com>
- Update to 1.3
  * Added delay option to autoselect.
  * Fixed bug #39, mouse pointer not captured with -a -p options.
  * Added -D option to specify the display to use.
  * Created full-check.yml to provide CI tests.
  * Using an updated README.md as replace for README.
  * Changed the cursor to indicate the selection mode.
  * Fixed some warnings and made compliant with GCC >= 8.0.
  * Updated manpage and help
  * Added (-n, --note) to draw a text.
  * Added (-l, --line) to define the line to use to select an area to capture.
  * Added a specifier ($a) to embed hostname in output file.
  * Added option: --overwrite or -o. Now, by default do not overwrite the file.
  * Added support to grab mouse pointer (-p option).
  * Added support to freeze the screen when selection is activated (-f option).
  * Fixed several issues.
  * Improved the manpage to show undocumented options.
  * Added --autoselect rectangle option
  * Added --focused option
  * Added an autogen.sh file.
  * Added some explanation about how to help the project.
  * Character cleanup for UTF-8 compatibility
  * Fixed a missing option for beep prevention.
  * Fixed spelling errors in final binary
  * Improved the GCC hardening.
  * Prevent arbitrary long file names
  * Several fixes in manpage.
- Remove 08_fix-beeping.patch
- Remove 07_fix-formatstring.patch
- Remove 06_manpagespace.patch
- Remove 05-addfocusedmanpage.patch
- Remove 04-focused.patch
- Remove 02_options.c.patch
- Remove 01_manpagefix.patch
- Remove 003_descmanpage.patch
* Fri Jun 26 2015 nemysis@gmx.ch
- Change Description
- Add sed, Fix paths and includes
* Tue Oct 28 2014 mimi.vx@gmail.com
- change licence to SUSE-Scrot
* Fri Oct 24 2014 mimi.vx@gmail.com
- rewrite spec file
- add debian patchset 13
    003_descmanpage.patch
    01_manpagefix.patch
    02_options.c.patch
    04-focused.patch
    05-addfocusedmanpage.patch
    06_manpagespace.patch
    07_fix-formatstring.patch
    08_fix-beeping.patch
